=======
Credits
=======

Development Leads
----------------

* Luisa Fernanda Velásquez González <lufvelasquezgo@unal.edu.co>
* Juan David Alzate Cardona <jdalzatec@unal.edu.co>

Contributors
------------

* Daniel Felipe Rodríguez Patiño <dfrodriguezp@unal.edu.co>
* Juan Sebastian Salcedo Gallo <jussalcedoga@unal.edu.co>
